.. image:: https://travis-ci.org/ambitioninc/django-entity-event-slack.png
   :target: https://travis-ci.org/ambitioninc/django-entity-event-slack

.. image:: https://coveralls.io/repos/ambitioninc/django-entity-event-slack/badge.png?branch=develop
    :target: https://coveralls.io/r/ambitioninc/django-entity-event-slack?branch=develop

.. image:: https://pypip.in/v/django-entity-event-slack/badge.png
    :target: https://pypi.python.org/pypi/django-entity-event-slack/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/django-entity-event-slack/badge.png
    :target: https://pypi.python.org/pypi/django-entity-event-slack/
    :alt: Number of PyPI downloads


django-entity-event-slack
=========================

A pushable Slack medium for the Django Entity Event framework.

Installation
------------
To install the latest release, type::

    pip install django-entity-event-slack

To install the latest code directly from source, type::

    pip install git+git://github.com/ambitioninc/django-entity-event-slack.git

Documentation
=============

Full documentation is available at http://django-entity-event-slack.readthedocs.org

License
=======
MIT License (see LICENSE)
